/**
 * @module
 * Helper functions for modifying webpack config.
 */
import { Configuration, Plugin, RuleSetRule, RuleSetUseItem } from "webpack";
/**
 * Replace minimizer library.
 * @param config webpack config
 * @param minimizer new minimizer
 * @returns modified webpack config
 */
export declare function replaceMinimizer(config: Configuration, minimizer: Plugin): Configuration;
declare type AnyConstructor = new (...args: any) => any;
/**
 * Append a plugin if not added to the plugins list yet.
 * @param config webpack config
 * @param ctor constructor of the plugin (function plugins are not supported)
 * @param item factory function returns an item to append
 * @returns modified webpack config
 */
export declare function safeAppendPlugin(config: Configuration, ctor: AnyConstructor, item: () => Plugin): Configuration;
/**
 * Remove a plugin from a plugin list in a given webpack config.
 * @param config webpack config
 * @param ctor constructor of the plugin to remove
 * @returns modified webpack config
 */
export declare function removePlugin(config: Configuration, ctor: AnyConstructor): Configuration;
declare type LoaderTester = (loader: RuleSetUseItem, rule: RuleSetRule) => boolean;
declare type LoaderReplacer = (loader: RuleSetUseItem) => RuleSetUseItem | null;
/**
 * Replace or Remove loader matching to `test` with a value returned from `replaceWith`.
 * @param config webpack config
 * @param test decides whether the loader is replaced (removed). think as 1st parameter of Array.prototype.filter
 * @param replaceWith a factory function returns a rule which takes place in. return null to remove the loader
 * @returns modified webpack config
 */
export declare function replaceLoader(config: Configuration, test: LoaderTester, replaceWith: LoaderReplacer): Configuration;
export {};
